@@ -29,7 +29,7 @@ def elapsed_timer():
 
 with elapsed_timer() as elapsed:
     sherlock = sherlock_explorer.SherlockExplorer()
-    sherlock.explore_object("TIC 257605131", input_lc_file="../TIC257605131_INP/lc_2.csv",
+    sherlock.explore_object("TIC 257605131",
                             auto_detrend_periodic_signals=False,
                             smooth=False, cadence=120)
 
